This is an attempt at creating a library for working with GeoGebra files. This is largely an educated guess and what works how as the documentation on the format is incredibly sparse. This is mostly incomplete and is mostly meant as a utility crate for Geo-AID.
Re-exports
Modules
- Raw GeoGebra structures.
Structs
- A circle in the construction
- A type-erased expression.
- High-level API for working with a Geogebra workspace.
- A line element of the Geogebra construction
- A list expression
- A number value
- A point element of the Geogebra construction
- A ray (half-line)
- A segment
- An immutable labeled expression. Passed by reference
Traits
- Marks this as addable
- Access for conic functions
- A trait for accessing list functions through convertible types
- Trait for accessing numeric functions
- Trait with point-related functions